# version

Show NAVIG version and system information.

Usage:
- `navig version` — show version with random quote
- `navig version --json` — output version in JSON format
- `navig -v` — quick version check

Examples:
- `navig version`
- `navig version --json`
